@@ -47,6 +47,9 @@ struct arglist {
 #define ARG_STRUCT	5
 
 
+
+
+
 /*
  * Plugin standard function templates
  */
@@ -358,10 +361,11 @@ ExtFunc int get_mac_addr(struct in_addr, char**);
 #define ACT_INIT		0
 
 
+#define LAUNCH_DISABLED 0
+#define LAUNCH_RUN      1
+#define LAUNCH_SILENT   2
+
 
-#define	LAUNCH_DISABLED 0
-#define LAUNCH_RUN	1
-#define LAUNCH_SILENT	2
 
 
 /*
@@ -375,8 +379,10 @@ ExtFunc int get_mac_addr(struct in_addr, char**);
 #define NESSUS_ENCAPS_SSLv2	3
 #define NESSUS_ENCAPS_SSLv3	4
 #define NESSUS_ENCAPS_TLSv1	5
+#define NESSUS_ENCAPS_TLSv10	NESSUS_ENCAPS_TLSv1
+#define NESSUS_ENCAPS_TLSv11	6
 
-#define IS_ENCAPS_SSL(x) ((x) >= NESSUS_ENCAPS_SSLv23 && (x) <= NESSUS_ENCAPS_TLSv1)
+#define IS_ENCAPS_SSL(x) ((x) >= NESSUS_ENCAPS_SSLv23 && (x) <= NESSUS_ENCAPS_TLSv11)
 
 /*
  * Transport layer options 
@@ -406,10 +412,8 @@ ExtFunc int    stream_set_options(int, int, int);
 
 ExtFunc int	stream_set_buffer(int, int);
 ExtFunc int	stream_get_buffer_sz (int);
-ExtFunc int	stream_get_err(int);
 
 #ifdef HAVE_SSL
-ExtFunc	       SSL*    stream_get_ssl(int);
 ExtFunc        X509*   stream_get_server_certificate(int);
 ExtFunc	       char*   stream_get_ascii_server_certificate(int);
 #endif
@@ -439,7 +443,6 @@ ExtFunc int stream_isset(int, fd_set*);
 ExtFunc int bpf_server();
 ExtFunc int bpf_open_live(char*, char*);
 ExtFunc u_char* bpf_next(int, int *);
-ExtFunc u_char* bpf_next_tv(int, int *, struct timeval *);
 ExtFunc void bpf_close(int);
 ExtFunc int  bpf_datalink(int);
 
@@ -493,8 +496,6 @@ int    kb_item_add_str(struct kb_item **, char *, char *);
 int    kb_item_set_str(struct kb_item **, char *, char *);
 int    kb_item_add_int(struct kb_item **, char *, int   );
 int    kb_item_set_int(struct kb_item **, char *, int   );
-void   kb_item_rm_all(struct kb_item **, char *);
-
 
 struct arglist * plug_get_oldstyle_kb(struct arglist * );
 
@@ -524,6 +525,9 @@ struct http_msg * http_share_send_recv_msg(struct arglist *, struct http_msg *);
 pid_t http_share_init(struct arglist *);
 int http_share_close(struct arglist *, pid_t);
 
+ExtFunc int http_recv_headers(int , char ** , int * );
+
+
 
 int os_send(int, void*, int, int);
 int os_recv(int, void*, int, int);
@@ -562,7 +566,6 @@ int internal_recv(int, char **, int *, int *);
 int internal_finished(int);
 	
 int fd_is_stream(int);
-int stream_pending(int);
 
 int send_fd(int, int);
 int recv_fd(int);
