@@ -138,12 +138,11 @@ static void rm_pcap(char * iface )
 	 next = bpc->next;
 	 pcap_close(bpc->pcap);
 	 efree(&bpc);
-	 if ( prev ) prev->next = next;
+	 if ( prev ) prev->next = bpc->next;
 	 else pcaps = next;
 	}
   prev = bpc;
-  if ( bpc != NULL )
-   bpc = bpc->next;
+  bpc = bpc->next;
  }
 }
 
@@ -506,14 +505,14 @@ static int add_clients(int soc)
 {
  fd_set rd;
  struct timeval tv = {0,0};
- unsigned int clnt;
+ int clnt;
  
  FD_ZERO(&rd);
  FD_SET(soc, &rd);
  if(select(soc+1, &rd, &rd, &rd, &tv) > 0)
  {
   struct sockaddr_un soca;
-  unsigned int len = sizeof(soca);
+  int len = sizeof(soca);
   clnt = accept(soc, (struct sockaddr*)&soca,&len); 
   if(clnt > 0)
   {
@@ -938,7 +937,7 @@ int bpf_open_live(char * iface, char * filter)
  if(iface == NULL)
   iface = pcap_lookupdev(errbuf);
  
- ret = pcap_open_live(iface, 1500, 0, 1, errbuf);
+ ret = pcap_open_live(iface, 1500, 0, 100, errbuf);
  if(ret == NULL)
  {
     printf("%s\n", errbuf);	 
@@ -975,25 +974,10 @@ u_char* bpf_next_tv(int bpf, int * caplen, struct timeval * tv)
 {
   u_char * p = NULL;
   struct pcap_pkthdr head;
-  struct timeval timeout, now;
 
-  gettimeofday(&timeout, NULL);
-  timeout.tv_sec += tv->tv_sec;
-  timeout.tv_usec += tv->tv_usec;
-  while ( timeout.tv_usec >= 1000000 ) {
-        timeout.tv_sec ++;
-        timeout.tv_usec -= 1000000;
-  }
   
- do {
-  p = (u_char*)pcap_next(pcaps[bpf], &head);
-  *caplen  = head.caplen;
-  if ( p != NULL ) break;
-  gettimeofday(&now, NULL);
- } while ( !((now.tv_sec > timeout.tv_sec) ||
-             (now.tv_sec == timeout.tv_sec && now.tv_usec >= timeout.tv_usec ) ));
-
-
+ p = (u_char*)pcap_next(pcaps[bpf], &head);
+ *caplen  = head.caplen;
  return p;
 }
 
