@@ -66,7 +66,9 @@ typedef struct {
   int		last_ssl_err;	/* Last SSL error code */
 #endif
  pid_t		pid;		/* Owner - for debugging only */
-
+#if 0
+  int		last_sock_err;	/* last socket level error */
+#endif
   char*		buf;		/* NULL if unbuffered */
   int		bufsz, bufcnt, bufptr;
 } nessus_connection;
@@ -737,6 +739,7 @@ open_stream_connection(args, port, transport, timeout)
   case NESSUS_ENCAPS_SSLv23:
   case NESSUS_ENCAPS_SSLv3:
   case NESSUS_ENCAPS_TLSv1:
+  case NESSUS_ENCAPS_TLSv11:
     renice_myself();
     cert   = kb_item_get_str(plug_get_kb(args), "SSL/cert");
     key    = kb_item_get_str(plug_get_kb(args), "SSL/key");
@@ -772,61 +775,64 @@ failed:
 }
 
 
+ExtFunc int
+open_stream_connection_unknown_encaps5(args, port, timeout, p, delta_t)
+ struct arglist * args;
+ unsigned int  port;
+ int timeout, * p;
+ int	*delta_t;		/* time, in micro-seconds */
+{
+  int fd;
+  int i;
+  struct timeval	tv1, tv2;
+  static int encaps[] = {
+#ifdef HAVE_SSL
+    NESSUS_ENCAPS_SSLv2,
+    NESSUS_ENCAPS_TLSv1,
+    NESSUS_ENCAPS_SSLv3,
+#endif
+    NESSUS_ENCAPS_IP
+  };
+ 
+#if DEBUG_SSL > 2
+  fprintf(stderr, "[%d] open_stream_connection_unknown_encaps: TCP:%d; %d\n",
+	  getpid(), port,timeout);
+#endif
+
+  for (i = 0; i < sizeof(encaps) / sizeof(*encaps); i ++)
+    {
+      if (delta_t != NULL) (void) gettimeofday(&tv1, NULL);
+      if ((fd = open_stream_connection(args, port, encaps[i], timeout)) >= 0)
+	{
+	  *p = encaps[i];
+#if DEBUG_SSL > 2
+	  fprintf(stderr, "[%d] open_stream_connection_unknown_encaps: TCP:%d -> transport=%d\n", getpid(), port, *p);
+#endif
+	  if (delta_t != NULL)
+	    {
+	      (void) gettimeofday(&tv2, NULL);
+	      *delta_t = (tv2.tv_sec - tv1.tv_sec) * 1000000 + (tv2.tv_usec - tv1.tv_usec);
+	    }
+	  return fd;
+	}
+      else if (__port_closed)
+	{
+#if DEBUG_SSL > 2
+	  fprintf(stderr, "[%d] open_stream_connection_unknown_encaps: TCP:%d -> closed\n", getpid(), port);
+#endif
+	  return -1;
+	}
+    }
+  return -1;
+}
+
 ExtFunc int
 open_stream_connection_unknown_encaps(args, port, timeout, p)
  struct arglist * args;
  unsigned int  port;
  int timeout, * p;
 {
- int fd;
- int i;
-#ifdef HAVE_SSL
- static int encaps[] = {
-   NESSUS_ENCAPS_SSLv2,
-   NESSUS_ENCAPS_TLSv1,
-   NESSUS_ENCAPS_SSLv3,
-    };
-#endif
- 
-#if DEBUG_SSL > 2
- fprintf(stderr, "[%d] open_stream_connection_unknown_encaps: TCP:%d; %d\n",
-	 getpid(), port,timeout);
-#endif
-
-#ifdef HAVE_SSL
- for (i = 0; i < sizeof(encaps) / sizeof(*encaps); i ++)
-   if ((fd = open_stream_connection(args, port, encaps[i], timeout)) >= 0)
-     {
-       *p = encaps[i];
-#if DEBUG_SSL > 2
-       fprintf(stderr, "[%d] open_stream_connection_unknown_encaps: TCP:%d -> transport=%d\n", getpid(), port, *p);
-#endif
-       return fd;
-     }
-   else if (__port_closed)
-     {
-#if DEBUG_SSL > 2
-       fprintf(stderr, "[%d] open_stream_connection_unknown_encaps: TCP:%d -> closed\n", getpid(), port);
-#endif
-       return -1;
-     }
-
- /* 
-  * No need to try to connect to the remote port twice
-  */
- if(__port_closed)
-  return -1;
-#endif 
- if ((fd = open_stream_connection(args, port, NESSUS_ENCAPS_IP, timeout)) >= 0)
- {
-  *p = NESSUS_ENCAPS_IP;
-#if DEBUG_SSL > 2
-       fprintf(stderr, "[%d] open_stream_connection_unknown_encaps: TCP:%d -> transport=%d\n", getpid(), port, *p);
-#endif
-  return fd;
- }
- 
- return -1;
+  return open_stream_connection_unknown_encaps5(args, port, timeout, p, NULL);
 }
 
 
@@ -1026,20 +1032,18 @@ read_stream_connection_unbuffered(fd, buf0, min_len, max_len)
           now = time(NULL);
 	  tv.tv_sec = INCR_TIMEOUT; tv.tv_usec = 0;
 	  select_status = select ( realfd + 1, &fdr, &fdw, NULL, &tv );
-#if 1 /* Possible workaround for an OpenSSL bug */
           if ( select_status == 0 )
           {
-      	  FD_ZERO(&fdr); FD_ZERO(&fdw);
+      	   FD_ZERO(&fdr); FD_ZERO(&fdw);
       	   FD_SET(realfd, &fdr); FD_SET(realfd, &fdw); 
           }
 	  else
-#endif
 	  if ( select_status > 0 )
 	    {
 	  ret = SSL_read(fp->ssl, buf + total, max_len - total);
 	  if (ret > 0)
 		{
-	    total += ret;
+	          total += ret;
 		  FD_SET(realfd, &fdr);
 		  FD_SET(realfd, &fdw); 
 		}
@@ -1049,7 +1053,8 @@ read_stream_connection_unbuffered(fd, buf0, min_len, max_len)
 	      if (ret <= 0)
 		{
 		  err = SSL_get_error(fp->ssl, ret);
-		  FD_ZERO(&fdr); FD_ZERO(&fdw);
+		  FD_ZERO(&fdr); 
+		  FD_ZERO(&fdw);
 		  switch (err)
 	   {
 		    case SSL_ERROR_WANT_READ:
@@ -1062,6 +1067,7 @@ read_stream_connection_unbuffered(fd, buf0, min_len, max_len)
 #if DEBUG_SSL > 2
 		      fprintf(stderr, "SSL_Connect[%d]: SSL_ERROR_WANT_WRITE\n", getpid());
 #endif
+		      FD_SET(realfd, &fdr);
 		      FD_SET(realfd, &fdw);
 		      break;
 
@@ -1463,6 +1469,8 @@ get_encaps_name(code)
     return "SSLv3";
   case NESSUS_ENCAPS_TLSv1:
     return "TLSv1";
+  case NESSUS_ENCAPS_TLSv11:
+    return "TLSv11";
   default:
    snprintf(str, sizeof(str), "[unknown transport layer - code %d (0x%x)]", code, code);
    return str;
@@ -1482,6 +1490,7 @@ get_encaps_through(code)
   case NESSUS_ENCAPS_SSLv23:
   case NESSUS_ENCAPS_SSLv3:
   case NESSUS_ENCAPS_TLSv1:
+  case NESSUS_ENCAPS_TLSv11:
     return " through SSL";
   default:
     snprintf(str, sizeof(str), " through unknown transport layer - code %d (0x%x)", code, code);
@@ -1520,7 +1529,7 @@ open_socket(struct sockaddr_in *paddr,
 
 #if defined NESSUS_CNX_LOCK
   if (lock_cnt == 0)
-{
+    {
       lock_fd = open(NESSUS_CNX_LOCK, O_RDWR|O_CREAT);
       if (lock_fd < 0)
 	nessus_perror(NESSUS_CNX_LOCK);
@@ -1592,6 +1601,7 @@ again:
 	      socket_close(soc);
 	      return -1;
 	    }
+	  
 	  if (opt == 0)
 	    break;
 #if DEBUG_SSL > 2
@@ -2261,3 +2271,45 @@ error:
  *data_sz = 0;
  return -1;
 }
+
+int
+get_and_clear_stream_socket_errno(int fd)
+{
+  nessus_connection	*fp = NULL;
+  int		err, opt_sz = sizeof(err);
+
+  if (NESSUS_STREAM(fd))
+    {
+      fp = connections + (fd - NESSUS_FD_OFF);
+      if (fp->fd < 0)
+	{
+	  fprintf(stderr,
+	    "[%d] get_and_clear_last_socket_error: closed Nessus fd <%d>\n", getpid(), fd);
+	  errno = EINVAL;
+	  return -1;
+	}
+    }
+#if DEBUG_SSL > 0
+  else
+    fprintf(stderr,
+	    "[%d] get_and_clear_last_socket_error: not a Nessus fd <%d>\n", getpid(), fd);
+#endif
+
+#if 0
+  if (fp->last_sock_err != 0)
+    {
+      err = fp->last_sock_err;
+      fp->last_sock_err = 0;
+      return err;
+    }
+#endif
+  if (getsockopt(fp != NULL ? fp->fd : fd, 
+		 SOL_SOCKET, SO_ERROR, &err, &opt_sz) < 0)
+    {
+      nessus_perror("getsockopt");
+      return -1;
+    }
+  else
+    return err;
+}
+
