@@ -356,7 +356,7 @@ struct interface_info *getinterfaces(int *howmany) {
 int getsourceip(struct in_addr *src, struct in_addr *dst) {
   int sd;
   struct sockaddr_in sock;
-  unsigned int socklen = sizeof(struct sockaddr_in);
+  int socklen = sizeof(struct sockaddr_in);
   unsigned short p1;
   
   
