@@ -410,7 +410,7 @@ ExtFunc
 struct arglist * plug_get_required_keys(desc)
  struct arglist * desc;
 {
- return _plug_get_required_keys(desc);
+ return store_fetch_required_keys(desc);
 }
 
 
@@ -444,7 +444,7 @@ ExtFunc
 struct arglist * plug_get_excluded_keys(desc)
  struct arglist * desc;
 {
- return _plug_get_excluded_keys(desc);
+ return store_fetch_excluded_keys(desc);
 }
 
 ExtFunc 
@@ -478,7 +478,7 @@ ExtFunc
 struct arglist * plug_get_required_ports(desc)
  struct arglist * desc;
 {
- return _plug_get_required_ports(desc);
+ return store_fetch_required_ports(desc);
 }
 
 
@@ -513,7 +513,7 @@ ExtFunc
 struct arglist * plug_get_required_udp_ports(desc)
  struct arglist * desc;
 {
- return _plug_get_required_udp_ports(desc);
+ return store_fetch_required_udp_ports(desc);
 }
  
 
@@ -549,10 +549,7 @@ ExtFunc
 struct arglist * plug_get_deps(desc)
  struct arglist * desc;
 {
- return _plug_get_deps(desc);
-#if 0
  return store_fetch_dependencies(desc);
-#endif
 }
 
 ExtFunc
@@ -576,10 +573,7 @@ ExtFunc
 int plug_get_timeout(desc)
  struct arglist * desc;
 {
- return _plug_get_timeout(desc);
-#if 0
  return store_fetch_timeout(desc);
-#endif
 }
 
 		
@@ -642,8 +636,7 @@ ExtFunc
 char * plug_get_name(desc)
  struct arglist * desc;
 {
- return _plug_get_name(desc);
- /*return store_fetch_name(desc);*/
+ return store_fetch_name(desc);
 }
 
 
@@ -902,7 +895,7 @@ int kb_get_port_state_proto(kb, prefs, portnum, proto)
  	return(1);
 	}
 	
- if(!port_in_ports(portnum, range, 0, num - 1)){
+ if(!port_in_ports(portnum, range, 0, num)){
        return unscanned_ports_as_closed(prefs);
        }
  
@@ -1023,7 +1016,10 @@ proto_post_wrapped(desc, port, proto, action, what)
  char * cve;
  char * bid;
  char * xref;
+ int do_send = 1;
  int i;
+ char ack;
+ int n = 0, e, l;
   
     
  if( action == NULL )action = plug_get_description(desc);
@@ -1291,9 +1287,7 @@ void _add_plugin_preference(prefs, p_name, name, type, defaul)
 
  pref = emalloc(strlen(p_name)+10+strlen(type)+strlen(cname));
  sprintf(pref, "%s[%s]:%s", p_name, type, cname);
- if ( arg_get_value(prefs, pref) == NULL )
-  arg_add_value(prefs, pref, ARG_STRING, strlen(defaul), estrdup(defaul));
-
+ arg_add_value(prefs, pref, ARG_STRING, strlen(defaul), estrdup(defaul));
  efree(&cname);
  efree(&pref);
 }
@@ -1411,15 +1405,15 @@ void * plug_get_fresh_key(args, name, type)
 
  e = internal_send(soc, name, INTERNAL_COMM_MSG_TYPE_KB|INTERNAL_COMM_KB_GET);
  if(e < 0){
-        fprintf(stderr, "[%d] plug_get_fresh_key:internal_send(%d): %s\n",getpid(), soc,strerror(errno));
-	goto err;
+        fprintf(stderr, "[%d] plug_get_fresh_key:internal_send(%d): %s\n",getpid(), soc,name, strerror(errno));
+	return NULL;
 	}
 
  internal_recv(soc, &buf, &bufsz, &msg); 
  if ( ( msg & INTERNAL_COMM_MSG_TYPE_KB ) == 0  )
  {
         fprintf(stderr, "[%d] plug_get_fresh_key:internal_send(%d): Unexpected message %d",getpid(), soc, msg);
-	goto err;
+	return NULL;
  }
 
  if ( msg & INTERNAL_COMM_KB_ERROR ) return NULL;
@@ -1427,20 +1421,14 @@ void * plug_get_fresh_key(args, name, type)
  {
   char * ret = estrdup(buf);
   *type = ARG_STRING;
-  efree(&buf);
   return ret;
  } 
  else if ( msg & INTERNAL_COMM_KB_SENDING_INT )
  {
-  int ret;
   *type = ARG_INT;
-  ret = atoi(buf);
-  efree(&buf);
-  return (void*)ret;
+  return (void*)atoi(buf);
  }
-err:
- if ( buf != NULL )efree(&buf);
- return NULL; 
+ else return NULL; 
 } 
 
 static void plug_set_replace_key(args, name, type, value, replace)
@@ -1525,6 +1513,7 @@ scanner_add_port(args, port, proto)
  const char * hn = plug_get_hostname(args);
  int len;
  int soc;
+ struct arglist * globs;
  int do_send = 1;
  static int confirm = -1;
  
@@ -1743,7 +1732,7 @@ plug_get_key(args, name, type)
       {
       int e;
       int status;
-      struct arglist * globals;
+      struct arglist * globals, * preferences = NULL;
   
       globals = arg_get_value(args, "globals");  
       upstream = (int)arg_get_value(globals, "global_socket");
@@ -1794,6 +1783,8 @@ ExtFunc unsigned int
 plug_get_host_open_port(struct arglist * desc)
 {
  struct kb_item ** kb = plug_get_kb(desc);
+ char * t;
+ int port = 0;
  struct kb_item * res, *k;
  int open21 = 0, open80 = 0;
 #define MAX_CANDIDATES 16
@@ -1985,20 +1976,15 @@ find_in_path(name, safe)
       sprintf(p2, "/%s", name);
       if (access(cmd, X_OK) == 0)
 	{
-	  struct stat	st;
-	  if (stat(cmd, &st) < 0)
-	    perror(cmd);
-	  else if (S_ISREG(st.st_mode))
-	    {
-	      *p2 = '\0';
+	  *p2 = '\0';
 #if 0
-	      fprintf(stderr, "find_in_path: %s found in %s\n", name, cmd);
+	  fprintf(stderr, "find_in_path: %s found in %s\n", name, cmd);
 #endif
-	      return cmd;
-	    }
+	  return cmd;
 	}
 #if 0
-	  fprintf(stderr, "find_in_path: No %s\n", cmd);
+      else
+	fprintf(stderr, "find_in_path: No %s\n", cmd);
 #endif
     }
   return NULL;
@@ -2016,8 +2002,7 @@ is_shell_command_present(name)
 ExtFunc int shared_socket_register ( struct arglist * args, int fd, char * name )
 {
  int soc; 
- int type;
- unsigned int opt_len = sizeof(type);
+ int type, opt_len = sizeof(type);
  int e;  
  soc = (int)arg_get_value(args, "SOCKET");
  if ( fd_is_stream(fd) )
