@@ -28,11 +28,11 @@
  */
 ExtFunc
 int 
-comm_send_status(globals, hostname, action, current,max)
+comm_send_status(globals, hostname, action, curr,max)
   struct arglist * globals;
   char * hostname;
   char * action;
-  int current, max;
+  int curr, max;
 {
  struct arglist * prefs = arg_get_value(globals,"preferences");
  char * pref = arg_get_value(prefs, "ntp_short_status");
@@ -61,16 +61,16 @@ comm_send_status(globals, hostname, action, current,max)
     {
     if(short_status)
       {
-      snprintf(buffer, sizeof(buffer), "s:%c:%s:%d:%d\n", action[0], hostname, current, max);
+      snprintf(buffer, sizeof(buffer), "s:%c:%s:%d:%d\n", action[0], hostname, curr, max);
       }
     else
      snprintf(buffer, sizeof(buffer),
 		"SERVER <|> STATUS <|> %s <|> %s <|> %d/%d <|> SERVER\n",
-		hostname, action, current, max);
+		hostname, action, curr, max);
     }
   else
    snprintf(buffer, sizeof(buffer), "SERVER <|> STAT <|> %s <|> %d/%d <|> SERVER\n",
-	      hostname, current, max);
+	      hostname, curr, max);
 	      
 	      
  internal_send(soc, buffer, INTERNAL_COMM_MSG_TYPE_DATA);
